@@ -556,7 +556,7 @@ CREATE_GETTER_AND_SETTER(Name)
 CREATE_GETTER_AND_SETTER(Description)
 CREATE_GETTER_AND_SETTER(Icon)
 
-#undef CREATE_GETTE_AND_SETTERR
+#undef CREATE_GETTER_AND_SETTER
 
 // Main
 
